@@ -6,7 +6,6 @@ mod component_descriptor;
 mod component_group;
 mod component_id;
 mod entity;
-mod entity_template;
 mod slice_tuple;
 
 pub use archetype_component_count::*;
@@ -17,5 +16,4 @@ pub use component_descriptor::*;
 pub use component_group::*;
 pub use component_id::*;
 pub use entity::*;
-pub use entity_template::*;
 pub use slice_tuple::*;
