@@ -1,5 +1,5 @@
 #![cfg_attr(feature = "const_type_name", feature(const_type_name))]
-#![cfg_attr(feature = "const_panic", feature(const_panic))]
+#![cfg_attr(feature = "const_fn_panic", feature(const_panic))]
 
 #[macro_use]
 pub mod macros;
