@@ -91,6 +91,14 @@ impl TryFrom<(Vec<ComponentDescriptor>, u16)> for ArchetypeRegistry {
                 Vec::with_capacity(64),
                 Vec::with_capacity(64),
                 Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
+                Vec::with_capacity(64),
             ],
             entities_per_pool,
         })
@@ -167,6 +175,14 @@ impl ArchetypeRegistry {
             ArchetypeComponentCount::Six => &mut self.unsorted_level_mapping[5],
             ArchetypeComponentCount::Seven => &mut self.unsorted_level_mapping[6],
             ArchetypeComponentCount::Eight => &mut self.unsorted_level_mapping[7],
+            ArchetypeComponentCount::Nine => &mut self.unsorted_level_mapping[8],
+            ArchetypeComponentCount::Ten => &mut self.unsorted_level_mapping[9],
+            ArchetypeComponentCount::Eleven => &mut self.unsorted_level_mapping[10],
+            ArchetypeComponentCount::Twelve => &mut self.unsorted_level_mapping[11],
+            ArchetypeComponentCount::Thirteen => &mut self.unsorted_level_mapping[12],
+            ArchetypeComponentCount::Fourteen => &mut self.unsorted_level_mapping[13],
+            ArchetypeComponentCount::Fifteen => &mut self.unsorted_level_mapping[14],
+            ArchetypeComponentCount::Sixteen => &mut self.unsorted_level_mapping[15],
         };
         vec.push(ArchetypeSortKey {
             archetype_id: id,
