@@ -7,10 +7,11 @@ use std::convert::*;
 
 #[test]
 pub fn test_archetype_registry() {
-    let component_types = vec![
-        ComponentDescriptor::from_component::<Position>(),
+    let mut component_types = vec![
         ComponentDescriptor::from_component::<Rotation>(),
+        ComponentDescriptor::from_component::<Position>(),
     ];
+    component_types.sort_by_key(|e| e.component_id);
     let mut registry =
         ArchetypeRegistry::try_from((component_types, DEFAULT_MAX_COMPONENTS_PER_POOL)).unwrap();
 
